# Django Ultimate Toolkit

The most useful tools for any django project

- Models
  - Mixins
    - TimeStampedModel
    - SoftDeleteModel
    - DBViewModel
    - MaterializedDBViewModel
  - Fields
    - CreatedAtField
    - UpdatedAtField
  - Managers
    - TimeStampedManager
    - SoftDeleteManager
    - DBViewManager
  - Fixes
    - DeleteUsingManager
- Tests
  - Factories ⭐️
  - faker
    - Sequence
    - RandInt
    - RandFloat
    - RandChoices
    - RandChoice
    - RandString
    - ForEach
- Misc
  - Singleton 
- Utils
  - typehint 
  - get_model_meta
  - Lazy
  - LazyCallable
  - env
    - PYTHON_VERSION
  - popitem
  - EMPTY